# BloodHound customqueries replacement description

Place in this directory your valid *.json BloodHound customqueries files.
When initializing a container, they will be `merged` together and will `replace` Exegol's at `~/.config/bloodhound/customqueries.json`.